@@ -7,14 +7,14 @@ from typing import List, Dict, Tuple, Iterable, Type, Union, Callable
 from zipfile import ZipFile
 import requests
 import numpy as np
+from numpy import ndarray
 import transformers
 import torch
-from numpy import ndarray
 from torch import nn, Tensor, device
 from torch.optim import Optimizer
 from torch.utils.data import DataLoader
-from tqdm.autonotebook import tqdm, trange
 import torch.multiprocessing as mp
+from tqdm.autonotebook import tqdm, trange
 import math
 import queue
 
@@ -33,7 +33,6 @@ class SentenceTransformer(nn.Sequential):
     :param modules: This parameter can be used to create custom SentenceTransformer models from scratch.
     :param device: Device (like 'cuda' / 'cpu') that should be used for computation. If None, checks if a GPU can be used.
     """
-
     def __init__(self, model_name_or_path: str = None, modules: Iterable[nn.Module] = None, device: str = None):
         if model_name_or_path is not None and model_name_or_path != "":
             logging.info("Load pretrained SentenceTransformer: {}".format(model_name_or_path))
@@ -130,14 +129,12 @@ class SentenceTransformer(nn.Sequential):
                num_workers: int = 0) -> Union[List[Tensor], ndarray, Tensor]:
         """
         Computes sentence embeddings
-
-
         :param sentences: the sentences to embed
         :param batch_size: the batch size used for the computation
         :param show_progress_bar: Output a progress bar when encode sentences
         :param output_value:  Default sentence_embedding, to get sentence embeddings. Can be set to token_embeddings to get wordpiece token embeddings.
         :param convert_to_numpy: If true, the output is a list of numpy vectors. Else, it is a list of pytorch tensors.
-        :param convert_to_tensor: If true, you get one large tensor as return. Overwrites any setting from conver_to_numpy
+        :param convert_to_tensor: If true, you get one large tensor as return. Overwrites any setting from convert_to_numpy
         :param is_pretokenized: If is_pretokenized=True, sentences must be a list of integers, containing the tokenized sentences with each token convert to the respective int.
         :param device: Which torch.device to use for the computation
         :param num_workers: Number of background-workers to tokenize data. Set to positive number to increase tokenization speed
@@ -159,7 +156,7 @@ class SentenceTransformer(nn.Sequential):
         self.to(device)
 
         all_embeddings = []
-        length_sorted_idx = np.argsort([len(sen) for sen in sentences])
+        length_sorted_idx = np.argsort([self._text_length(sen) for sen in sentences])
         sentences_sorted = [sentences[idx] for idx in length_sorted_idx]
         inp_dataset = EncodeDataset(sentences_sorted, model=self, is_tokenized=is_pretokenized)
         inp_dataloader = DataLoader(inp_dataset, batch_size=batch_size, collate_fn=self.smart_batching_collate_text_only, num_workers=num_workers, shuffle=False)
@@ -201,8 +198,8 @@ class SentenceTransformer(nn.Sequential):
 
     def start_multi_process_pool(self, target_devices: List[str] = None, encode_batch_size: int = 32):
         """
-        Starts multi process to process the encode with several, independent  process.
-        This methos is recommend if you want to encode on multiple GPUs. It is advised
+        Starts multi process to process the encoding with several, independent processes.
+        This method is recommended if you want to encode on multiple GPUs. It is advised
         to start only one process per GPU. This method works together with encode_multi_process
 
         :param target_devices: PyTorch target devices, e.g. cuda:0, cuda:1... If None, all available CUDA devices will be used
@@ -247,7 +244,7 @@ class SentenceTransformer(nn.Sequential):
         pool['output'].close()
 
 
-    def encode_multi_process(self, sentences: List[str], pool: Dict[str, object], is_pretokenized: bool = False):
+    def encode_multi_process(self, sentences: List[str], pool: Dict[str, object], is_pretokenized: bool = False, chunk_size=None):
         """
         This method allows to run encode() on multiple GPUs. The sentences are chunked into smaller packages
         and sent to individual processes, which encode these on the different GPUs. This method is only suitable
@@ -256,34 +253,32 @@ class SentenceTransformer(nn.Sequential):
         :param sentences: List of sentences
         :param pool: A pool of workers started with SentenceTransformer.start_multi_process_pool
         :param is_pretokenized: If true, no tokenization will be applied. It is expected that the input sentences are list of ints.
+        :param chunk_size: Sentences are chunked and sent to the individual processes. If none, it determine a sensible size.
         :return: Numpy matrix with all embeddings
         """
 
-        chunk_size = min(math.ceil(len(sentences) / len(pool["processes"]) / 10), 5000)
+        if chunk_size is None:
+            chunk_size = min(math.ceil(len(sentences) / len(pool["processes"]) / 10), 5000)
+
         logging.info("Chunk data into packages of size {}".format(chunk_size))
 
-        if is_pretokenized:
-            sentences_tokenized = sentences
-        else:
-            sentences_tokenized = map(self.tokenize, sentences)
-
         input_queue = pool['input']
-        num_chunks = 0
+        last_chunk_id = 0
         chunk = []
 
-        for sentence in sentences_tokenized:
+        for sentence in sentences:
             chunk.append(sentence)
             if len(chunk) >= chunk_size:
-                input_queue.put([num_chunks, chunk])
-                num_chunks += 1
+                input_queue.put([last_chunk_id, is_pretokenized, chunk])
+                last_chunk_id += 1
                 chunk = []
 
         if len(chunk) > 0:
-            input_queue.put([num_chunks, chunk])
-            num_chunks += 1
+            input_queue.put([last_chunk_id, chunk])
+            last_chunk_id += 1
 
         output_queue = pool['output']
-        results_list = sorted([output_queue.get() for _ in range(num_chunks)], key=lambda x: x[0])
+        results_list = sorted([output_queue.get() for _ in range(last_chunk_id)], key=lambda x: x[0])
         embeddings = np.concatenate([result[1] for result in results_list])
         return embeddings
 
@@ -294,8 +289,8 @@ class SentenceTransformer(nn.Sequential):
         """
         while True:
             try:
-                id, sentences = input_queue.get()
-                embeddings = model.encode(sentences, device=target_device, is_pretokenized=True, show_progress_bar=False, convert_to_numpy=True, batch_size=encode_batch_size)
+                id, is_pretokenized, sentences = input_queue.get()
+                embeddings = model.encode(sentences, device=target_device, is_pretokenized=is_pretokenized, show_progress_bar=False, convert_to_numpy=True, batch_size=encode_batch_size)
                 results_queue.put([id, embeddings])
             except queue.Empty:
                 break
@@ -356,6 +351,7 @@ class SentenceTransformer(nn.Sequential):
     def smart_batching_collate(self, batch):
         """
         Transforms a batch from a SmartBatchingDataset to a batch of tensors for the model
+        Here, batch is a list of tuples: [(tokens, label), ...]
 
         :param batch:
             a batch from a SmartBatchingDataset
@@ -371,7 +367,7 @@ class SentenceTransformer(nn.Sequential):
             labels.append(label)
             for i in range(num_texts):
                 paired_texts[i].append(tokens[i])
-                max_seq_len[i] = max(max_seq_len[i], len(tokens[i]))
+                max_seq_len[i] = max(max_seq_len[i], self._text_length(tokens[i]))
 
         features = []
         for idx in range(num_texts):
@@ -389,7 +385,6 @@ class SentenceTransformer(nn.Sequential):
 
 
             for feature_name in feature_lists:
-                #feature_lists[feature_name] = torch.tensor(np.asarray(feature_lists[feature_name]))
                 feature_lists[feature_name] = torch.cat(feature_lists[feature_name])
 
             features.append(feature_lists)
@@ -399,7 +394,8 @@ class SentenceTransformer(nn.Sequential):
 
     def smart_batching_collate_text_only(self, batch):
         """
-        Transforms a batch from a SmartBatchingDataset to a batch of tensors for the model
+        Transforms a batch from a SmartBatchingDataset to a batch of tensors for the model.
+        Here, batch is a list of texts
 
         :param batch:
             a batch from a SmartBatchingDataset
@@ -407,7 +403,7 @@ class SentenceTransformer(nn.Sequential):
             a batch of tensors for the model
         """
 
-        max_seq_len = max([len(text) for text in batch])
+        max_seq_len = max([self._text_length(text) for text in batch])
         feature_lists = {}
 
         for text in batch:
@@ -423,7 +419,16 @@ class SentenceTransformer(nn.Sequential):
 
         return feature_lists
 
-
+    def _text_length(self, text: Union[List[int], List[List[int]]]):
+        """
+        Help function to get the length for the input text. Text can be either
+        a list of ints (which means a single text as input), or a tuple of list of ints
+        (representing several text inputs to the model).
+        """
+        if isinstance(text[0], int):
+            return len(text)
+        else:
+            return sum([len(t) for t in text])
 
     def fit(self,
             train_objectives: Iterable[Tuple[DataLoader, nn.Module]],
