@@ -1,23 +1,20 @@
-from . import SentenceEvaluator, SimilarityFunction
-from torch.utils.data import DataLoader
-
-import torch
+from . import SentenceEvaluator
 import logging
-from tqdm import tqdm
-from ..util import batch_to_device
+from ..util import pytorch_cos_sim
 import os
 import csv
 import numpy as np
 import scipy.spatial
-from typing import List, Tuple
+from typing import List
+import torch
 
 class TranslationEvaluator(SentenceEvaluator):
     """
     Given two sets of sentences in different languages, e.g. (en_1, en_2, en_3...) and (fr_1, fr_2, fr_3, ...),
-    and assuming that en_i = fr_i.
+    and assuming that fr_i is the translation of en_i.
     Checks if vec(en_i) has the highest similarity to vec(fr_i). Computes the accurarcy in both directions
     """
-    def __init__(self, source_sentences: List[str], target_sentences: List[str],  show_progress_bar: bool = False, batch_size: int = 8, name: str = ''):
+    def __init__(self, source_sentences: List[str], target_sentences: List[str],  show_progress_bar: bool = False, batch_size: int = 16, name: str = '', print_wrong_matches: bool = False):
         """
         Constructs an evaluator based for the dataset
 
@@ -27,14 +24,15 @@ class TranslationEvaluator(SentenceEvaluator):
             List of sentences in source language
         :param target_sentences:
             List of sentences in target language
-        :param main_similarity:
-            the similarity metric that will be used for the returned score
+        :param print_wrong_matches:
+            Prints incorrect matches
         """
         self.source_sentences = source_sentences
         self.target_sentences = target_sentences
         self.name = name
         self.batch_size = batch_size
         self.show_progress_bar = show_progress_bar
+        self.print_wrong_matches = print_wrong_matches
 
         assert len(self.source_sentences) == len(self.target_sentences)
 
@@ -55,26 +53,41 @@ class TranslationEvaluator(SentenceEvaluator):
 
         logging.info("Evaluating translation matching Accuracy on "+self.name+" dataset"+out_txt)
 
-        embeddings1 = np.asarray(model.encode(self.source_sentences, show_progress_bar=self.show_progress_bar, batch_size=self.batch_size))
-        embeddings2 = np.asarray(model.encode(self.target_sentences, show_progress_bar=self.show_progress_bar, batch_size=self.batch_size))
+        embeddings1 = torch.stack(model.encode(self.source_sentences, show_progress_bar=self.show_progress_bar, batch_size=self.batch_size, convert_to_numpy=False))
+        embeddings2 = torch.stack(model.encode(self.target_sentences, show_progress_bar=self.show_progress_bar, batch_size=self.batch_size, convert_to_numpy=False))
 
-        distances = -scipy.spatial.distance.cdist(embeddings1, embeddings2, "cosine")
+
+        cos_sims = pytorch_cos_sim(embeddings1, embeddings2).detach().cpu().numpy()
 
         correct_src2trg = 0
         correct_trg2src = 0
-        for i in range(len(distances)):
-            max_idx = np.argmax(distances[i])
+
+        for i in range(len(cos_sims)):
+            max_idx = np.argmax(cos_sims[i])
+
             if i == max_idx:
                 correct_src2trg += 1
+            elif self.print_wrong_matches:
+                print("i:", i, "j:", max_idx, "INCORRECT" if i != max_idx else "CORRECT")
+                print("Src:", self.source_sentences[i])
+                print("Trg:", self.target_sentences[max_idx])
+                print("Argmax score:", cos_sims[i][max_idx], "vs. correct score:", cos_sims[i][i])
 
-        distances = distances.T
-        for i in range(len(distances)):
-            max_idx = np.argmax(distances[i])
+                results = zip(range(len(cos_sims[i])), cos_sims[i])
+                results = sorted(results, key=lambda x: x[1], reverse=True)
+                for idx, score in results[0:5]:
+                    print("\t", idx, "(Score: %.4f)" % (score), self.target_sentences[idx])
+
+
+
+        cos_sims = cos_sims.T
+        for i in range(len(cos_sims)):
+            max_idx = np.argmax(cos_sims[i])
             if i == max_idx:
                 correct_trg2src += 1
 
-        acc_src2trg = correct_src2trg / len(distances)
-        acc_trg2src = correct_trg2src / len(distances)
+        acc_src2trg = correct_src2trg / len(cos_sims)
+        acc_trg2src = correct_trg2src / len(cos_sims)
 
         logging.info("Accuracy src2trg: {:.2f}".format(acc_src2trg*100))
         logging.info("Accuracy trg2src: {:.2f}".format(acc_trg2src*100))
