@@ -5,16 +5,15 @@ class InputExample:
     """
     Structure for one input example with texts, the label and a unique id
     """
-    def __init__(self, guid: str = '', texts: List[str] = None, texts_tokenized: List[List[int]] = None, label: Union[int, float] = None):
+    def __init__(self, guid: str = '', texts: List[str] = None, texts_tokenized: List[List[int]] = None, label: Union[int, float] = 0):
         """
         Creates one InputExample with the given texts, guid and label
 
-        str.strip() is called on both texts.
 
         :param guid
             id for the example
         :param texts
-            the texts for the example
+            the texts for the example. Note, str.strip() is called on the texts
         :param texts_tokenized
             Optional: Texts that are already tokenized. If texts_tokenized is passed, texts must not be passed.
         :param label
